==> gorilla-notes-0.4.0.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$singlePlayer.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_player$lib$singlePlayer=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _extends(){_extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i],key;for(key in source)Object.prototype.hasOwnProperty.call(source,key)&&(target[key]=source[key])}return target};return _extends.apply(this,arguments)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);
enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,
key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,
staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==
typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in
obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=function(activePlayer){var _class,_temp;return _temp=_class=function(_Component){function SinglePlayer(){if(!(this instanceof SinglePlayer))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,
[this].concat(args));_defineProperty(_assertThisInitialized(_this),"config",(0,_utils.getConfig)(_this.props,_props.defaultProps,!0));_defineProperty(_assertThisInitialized(_this),"getDuration",function(){return _this.player?_this.player.getDuration():null});_defineProperty(_assertThisInitialized(_this),"getCurrentTime",function(){return _this.player?_this.player.getCurrentTime():null});_defineProperty(_assertThisInitialized(_this),"getSecondsLoaded",function(){return _this.player?_this.player.getSecondsLoaded():
null});_defineProperty(_assertThisInitialized(_this),"getInternalPlayer",function(){return _this.player?_this.player.getInternalPlayer(0<arguments.length&&void 0!==arguments[0]?arguments[0]:"player"):null});_defineProperty(_assertThisInitialized(_this),"seekTo",function(fraction,type){if(!_this.player)return null;_this.player.seekTo(fraction,type)});_defineProperty(_assertThisInitialized(_this),"ref",function(player){_this.player=player});return _this}_inherits(SinglePlayer,_Component);var _super=
_createSuper(SinglePlayer);_createClass(SinglePlayer,[{key:"shouldComponentUpdate",value:function(nextProps){return!(0,_utils.isEqual)(this.props,nextProps)}},{key:"componentDidUpdate",value:function(){this.config=(0,_utils.getConfig)(this.props,_props.defaultProps)}},{key:"render",value:function(){var _this$config$file=this.config.file,forceAudio=_this$config$file.forceAudio,forceHLS=_this$config$file.forceHLS,forceDASH=_this$config$file.forceDASH;_this$config$file=_this$config$file.forceVideo||
forceAudio||forceHLS||forceDASH;if(!activePlayer.canPlay(this.props.url)&&!_this$config$file)return null;forceDASH=this.props;_this$config$file=forceDASH.style;forceAudio=forceDASH.width;forceHLS=forceDASH.height;forceDASH=forceDASH.wrapper;var otherProps=(0,_utils.omit)(this.props,SUPPORTED_PROPS,_props.DEPRECATED_CONFIG_PROPS);return _react["default"].createElement(forceDASH,_extends({style:_objectSpread({},_this$config$file,{width:forceAudio,height:forceHLS})},otherProps),_react["default"].createElement(_Player["default"],
_extends({},this.props,{ref:this.ref,activePlayer,config:this.config})))}}]);return SinglePlayer}(_react.Component),_defineProperty(_class,"displayName","".concat(activePlayer.displayName,"Player")),_defineProperty(_class,"propTypes",_props.propTypes),_defineProperty(_class,"defaultProps",_props.defaultProps),_defineProperty(_class,"canPlay",activePlayer.canPlay),_temp};var _react=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};
var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),
_props=require("module$node_modules$react_player$lib$props"),_utils=require("module$node_modules$react_player$lib$utils"),_Player=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$Player")),SUPPORTED_PROPS=Object.keys(_props.propTypes)}
//# sourceMappingURL=module$node_modules$react_player$lib$singlePlayer.js.map

==> gorilla-notes-0.5.2.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$singlePlayer.js <==
shadow$provide.module$node_modules$react_player$lib$singlePlayer=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _extends(){_extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i],key;for(key in source)Object.prototype.hasOwnProperty.call(source,key)&&(target[key]=source[key])}return target};return _extends.apply(this,arguments)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);
enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,
key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,
staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==
typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in
obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=function(activePlayer){var _class,_temp;return _temp=_class=function(_Component){function SinglePlayer(){if(!(this instanceof SinglePlayer))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,
[this].concat(args));_defineProperty(_assertThisInitialized(_this),"config",(0,_utils.getConfig)(_this.props,_props.defaultProps,!0));_defineProperty(_assertThisInitialized(_this),"getDuration",function(){return _this.player?_this.player.getDuration():null});_defineProperty(_assertThisInitialized(_this),"getCurrentTime",function(){return _this.player?_this.player.getCurrentTime():null});_defineProperty(_assertThisInitialized(_this),"getSecondsLoaded",function(){return _this.player?_this.player.getSecondsLoaded():
null});_defineProperty(_assertThisInitialized(_this),"getInternalPlayer",function(){return _this.player?_this.player.getInternalPlayer(0<arguments.length&&void 0!==arguments[0]?arguments[0]:"player"):null});_defineProperty(_assertThisInitialized(_this),"seekTo",function(fraction,type){if(!_this.player)return null;_this.player.seekTo(fraction,type)});_defineProperty(_assertThisInitialized(_this),"ref",function(player){_this.player=player});return _this}_inherits(SinglePlayer,_Component);var _super=
_createSuper(SinglePlayer);_createClass(SinglePlayer,[{key:"shouldComponentUpdate",value:function(nextProps){return!(0,_utils.isEqual)(this.props,nextProps)}},{key:"componentDidUpdate",value:function(){this.config=(0,_utils.getConfig)(this.props,_props.defaultProps)}},{key:"render",value:function(){var _this$config$file=this.config.file,forceAudio=_this$config$file.forceAudio,forceHLS=_this$config$file.forceHLS,forceDASH=_this$config$file.forceDASH;_this$config$file=_this$config$file.forceVideo||
forceAudio||forceHLS||forceDASH;if(!activePlayer.canPlay(this.props.url)&&!_this$config$file)return null;forceDASH=this.props;_this$config$file=forceDASH.style;forceAudio=forceDASH.width;forceHLS=forceDASH.height;forceDASH=forceDASH.wrapper;var otherProps=(0,_utils.omit)(this.props,SUPPORTED_PROPS,_props.DEPRECATED_CONFIG_PROPS);return _react["default"].createElement(forceDASH,_extends({style:_objectSpread({},_this$config$file,{width:forceAudio,height:forceHLS})},otherProps),_react["default"].createElement(_Player["default"],
_extends({},this.props,{ref:this.ref,activePlayer:activePlayer,config:this.config})))}}]);return SinglePlayer}(_react.Component),_defineProperty(_class,"displayName","".concat(activePlayer.displayName,"Player")),_defineProperty(_class,"propTypes",_props.propTypes),_defineProperty(_class,"defaultProps",_props.defaultProps),_defineProperty(_class,"canPlay",activePlayer.canPlay),_temp};var _react=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};
var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),
_props=require("module$node_modules$react_player$lib$props"),_utils=require("module$node_modules$react_player$lib$utils"),_Player=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$Player")),SUPPORTED_PROPS=Object.keys(_props.propTypes)}
//# sourceMappingURL=module$node_modules$react_player$lib$singlePlayer.js.map
